<p align="center"><img width="40%" src="https://github.com/AIModelShare/aimodelshare/blob/master/docs/aimodshare_banner.jpg" /></p>

# Model Deployment in Less than One Minute
<p align="center"><img width="60%" src="https://aimodelsharecontent.s3.amazonaws.com/ModelDeploymentDiagram.jpeg" /></p>

## Tutorials: How to Prepare Files for Model Deployment
| Data Type   | Model           | Framework|Tutorial |
| ----------- |:---------------:| --------:| --------:|
| Image       | Classification  | Keras    |[Quick Start Example](https://github.com/AIModelShare/aimodelshare/blob/master/tutorials/notebooks/image_keras.ipynb) |
| Image       | Classification  | Keras    |[Example](https://github.com/AIModelShare/aimodelshare/blob/master/tutorials/notebooks/image_classification.ipynb) |
| Tabular     | Classification  | Keras    |[Example](https://github.com/AIModelShare/aimodelshare/blob/master/tutorials/notebooks/tabular_data_classification.ipynb) |
| Tabular     | Regression      | Keras    |[Example](https://github.com/AIModelShare/aimodelshare/blob/master/tutorials/notebooks/tabular_data_regression.ipynb) |
| Text        | Classification  | Keras    |[Example](https://github.com/AIModelShare/aimodelshare/blob/master/tutorials/notebooks/text_data_classification.ipynb) |

| Data Type   | Model           | Framework|Tutorial |
| ----------- |:---------------:| --------:| --------:|
| Tabular     | Classification  | Scikit-learn    |[Example](https://github.com/AIModelShare/aimodelshare/blob/master/tutorials/notebooks/tabular_sklearn_classification.ipynb) |
| Tabular     | Regression      | Scikit-learn    |[Example](https://github.com/AIModelShare/aimodelshare/blob/master/tutorials/notebooks/tabular_sklearn_regression.ipynb) |
| Text        | Classification  | Scikit-learn    |[Example](https://github.com/AIModelShare/aimodelshare/blob/master/tutorials/notebooks/text_sklearn_classification.ipynb) |

| Data Type   | Model           | Framework|Tutorial |
| ----------- |:---------------:| --------:| --------:|
| Image       | Classification  | PyTorch  |[Quick Start Example](https://github.com/AIModelShare/aimodelshare/blob/master/tutorials/notebooks/image_pytorch_classification_cifar.ipynb) |
| Image       | Classification  | PyTorch  |[Example](https://github.com/AIModelShare/aimodelshare/blob/master/tutorials/notebooks/image_pytorch_classification.ipynb) |
<h2 align="center">Simply write a function to preprocess your data, fit your model, save it, and then deploy it!</h2>
<p align="center"><img width="60%" src="https://aimodelsharecontent.s3.amazonaws.com/ModelandPreprocessorObjectPreparation.jpeg" /></p>
